@@ -26,7 +26,11 @@ class CypherTransactionBlock:
                  transactionUid=None,
                  origin=None,
                  callingCF=None,
-                 sqlClient=None):
+                 sqlClient=None,
+                 originDocUid=None,
+                 appUid=None):
+        self.docUid = originDocUid
+        self.appUid = appUid
         self.createdAt = datetime.now(timezone.utc)
         self.numRetries = 0
         self.lastUpdatedAt = datetime.now(timezone.utc)
@@ -61,7 +65,9 @@ class CypherTransactionBlock:
             "errors": self.errors,
             "durations": self.durations,
             "callingCF": self.callingCF,
-            "timeInQ": self.timeInQ
+            "timeInQ": self.timeInQ,
+            "docUid": self.docUid,
+            "appUid": self.appUid
         }
 
     def instanceToSerial(self):
@@ -85,151 +91,161 @@ class CypherTransactionBlock:
         self.durations = um.getval(dict_, "durations")
         self.callingCF = um.getval(dict_, "callingCF")
         self.timeInQ = um.getval(dict_, "timeInQ")
+        self.docUid = um.getval(dict_, "docUid")
+        self.appUid = um.getval(dict_, "appUid")
+
         self.setJson()
 
     def registerChangeInSql(self, newState, error=None):
         """
         Registers the change in the state of this CTB in the monkee.q table in SQL
         """
-        if self.transactionUid is not None:
-            sqlInsertQuery = (
-                """ INSERT INTO """ + self.qLogTable + """(q_uid, status)
-            values ( %s,%s )
-            """
-            )
-            with self.sqlClient.connect() as conn:
-                conn.execute(
-                    sqlInsertQuery,
-                    [
-                        self.transactionUid,
-                        newState
-                    ],
-                )
-
-            if newState == 'create':
+        try:
+            if self.transactionUid is not None:
                 sqlInsertQuery = (
-                    """ INSERT INTO """ + self.qTable + """(q_uid, ctb_serial, created_at)
-                select %s,%s,%s
-                where not exists (select * from """ + self.qTable + """ where q_uid=%s)"""
+                    """ INSERT INTO """ + self.qLogTable + """(q_uid, status)
+                values ( %s,%s )
+                """
                 )
                 with self.sqlClient.connect() as conn:
                     conn.execute(
                         sqlInsertQuery,
                         [
                             self.transactionUid,
-                            json.dumps(self.json, cls=um.RoundTripEncoder),
-                            self.createdAt,
-                            self.transactionUid
-                        ],
-                    )
-            elif newState == 'toWaiting':
-                sqlQuery = (
-                    """ UPDATE """ + self.qTable + """ 
-                    SET waiting_q_at = %s
-                    WHERE q_uid = %s"""
-                )
-                with self.sqlClient.connect() as conn:
-                    conn.execute(
-                        sqlQuery,
-                        [
-                            datetime.now(timezone.utc),
-                            self.transactionUid
-
-                        ],
-                    )
-            elif newState == 'toWorking':
-                sqlQuery = (
-                    """ UPDATE """ + self.qTable + """ 
-                    SET working_q_at = %s
-                    WHERE q_uid = %s"""
-                )
-                with self.sqlClient.connect() as conn:
-                    conn.execute(
-                        sqlQuery,
-                        [
-                            datetime.now(timezone.utc),
-                            self.transactionUid
-
+                            newState
                         ],
                     )
 
-            elif newState == 'toCompleted':
-                sqlQuery = (
-                    """ UPDATE """ + self.qTable + """ 
-                    SET compl_q_at = %s
-                    WHERE q_uid = %s"""
-                )
-                with self.sqlClient.connect() as conn:
-                    conn.execute(
-                        sqlQuery,
-                        [
-                            datetime.now(timezone.utc),
-                            self.transactionUid
-
-                        ],
+                if newState == 'create':
+                    sqlInsertQuery = (
+                        """ INSERT INTO """ + self.qTable + """(app_uid, uid, q_uid, ctb_serial, created_at, cf)
+                    select %s,%s,%s,%s,%s,%s
+                    where not exists (select * from """ + self.qTable + """ where q_uid=%s)"""
                     )
-
-            elif newState == 'executeStart':
-                sqlQuery = (
-                    """ UPDATE """ + self.qTable + """ 
-                    SET exec_started_at = %s
-                    WHERE q_uid = %s"""
-                )
-                with self.sqlClient.connect() as conn:
-                    conn.execute(
-                        sqlQuery,
-                        [
-                            datetime.now(timezone.utc),
-                            self.transactionUid
-
-                        ],
+                    with self.sqlClient.connect() as conn:
+                        conn.execute(
+                            sqlInsertQuery,
+                            [
+                                self.appUid,
+                                self.docUid,
+                                self.transactionUid,
+                                json.dumps(self.json, cls=um.RoundTripEncoder),
+                                self.createdAt,
+                                self.callingCF,
+                                self.transactionUid
+                            ],
+                        )
+                elif newState == 'toWaiting':
+                    sqlQuery = (
+                        """ UPDATE """ + self.qTable + """ 
+                        SET waiting_q_at = %s
+                        WHERE q_uid = %s"""
                     )
-            elif newState == 'executeEnd':
-                sqlQuery = (
-                    """ UPDATE """ + self.qTable + """ 
-                    SET exec_completed_at = %s
-                    WHERE q_uid = %s"""
-                )
-                with self.sqlClient.connect() as conn:
-                    conn.execute(
-                        sqlQuery,
-                        [
-                            datetime.now(timezone.utc),
-                            self.transactionUid
+                    with self.sqlClient.connect() as conn:
+                        conn.execute(
+                            sqlQuery,
+                            [
+                                datetime.now(timezone.utc),
+                                self.transactionUid
 
-                        ],
+                            ],
+                        )
+                elif newState == 'toWorking':
+                    sqlQuery = (
+                        """ UPDATE """ + self.qTable + """ 
+                        SET working_q_at = %s
+                        WHERE q_uid = %s"""
                     )
-            elif newState == 'error':
-                sqlQuery = (
-                    """ UPDATE """ + self.qTable + """ 
-                    SET errors = %s
-                    WHERE q_uid = %s"""
-                )
-                with self.sqlClient.connect() as conn:
-                    conn.execute(
-                        sqlQuery,
-                        [
-                            error,
-                            self.transactionUid
+                    with self.sqlClient.connect() as conn:
+                        conn.execute(
+                            sqlQuery,
+                            [
+                                datetime.now(timezone.utc),
+                                self.transactionUid
 
-                        ],
+                            ],
+                        )
+
+                elif newState == 'toCompleted':
+                    sqlQuery = (
+                        """ UPDATE """ + self.qTable + """ 
+                        SET compl_q_at = %s
+                        WHERE q_uid = %s"""
                     )
+                    with self.sqlClient.connect() as conn:
+                        conn.execute(
+                            sqlQuery,
+                            [
+                                datetime.now(timezone.utc),
+                                self.transactionUid
 
-            elif newState == 'outOfWorkingQ':
-                sqlQuery = (
-                    """ UPDATE """ + self.qTable + """ 
-                    SET out_of_working_q_at = %s
-                    WHERE q_uid = %s"""
-                )
-                with self.sqlClient.connect() as conn:
-                    conn.execute(
-                        sqlQuery,
-                        [
-                            datetime.now(timezone.utc),
-                            self.transactionUid
+                            ],
+                        )
 
-                        ],
+                elif newState == 'executeStart':
+                    sqlQuery = (
+                        """ UPDATE """ + self.qTable + """ 
+                        SET exec_started_at = %s
+                        WHERE q_uid = %s"""
                     )
+                    with self.sqlClient.connect() as conn:
+                        conn.execute(
+                            sqlQuery,
+                            [
+                                datetime.now(timezone.utc),
+                                self.transactionUid
+
+                            ],
+                        )
+                elif newState == 'executeEnd':
+                    sqlQuery = (
+                        """ UPDATE """ + self.qTable + """ 
+                        SET exec_completed_at = %s,
+                        errors = case when errors is not null then 'None. Original error = ' || errors else null end
+                        WHERE q_uid = %s"""
+                    )
+                    with self.sqlClient.connect() as conn:
+                        conn.execute(
+                            sqlQuery,
+                            [
+                                datetime.now(timezone.utc),
+                                self.transactionUid
+
+                            ],
+                        )
+                elif newState == 'error':
+                    sqlQuery = (
+                        """ UPDATE """ + self.qTable + """ 
+                        SET errors = %s
+                        WHERE q_uid = %s"""
+                    )
+                    with self.sqlClient.connect() as conn:
+                        conn.execute(
+                            sqlQuery,
+                            [
+                                error,
+                                self.transactionUid
+
+                            ],
+                        )
+
+                elif newState == 'outOfWorkingQ':
+                    sqlQuery = (
+                        """ UPDATE """ + self.qTable + """ 
+                        SET out_of_working_q_at = %s
+                        WHERE q_uid = %s"""
+                    )
+                    with self.sqlClient.connect() as conn:
+                        conn.execute(
+                            sqlQuery,
+                            [
+                                datetime.now(timezone.utc),
+                                self.transactionUid
+
+                            ],
+                        )
+        except Exception as e:
+            logging.error("registerChangeInSql: {}".format(repr(e)))
 
 
 class CypherTransactionBlockWorker:
@@ -269,7 +285,6 @@ class CypherTransactionBlockWorker:
 
         if howLong >= forHowLong - inactivityBuffer and self.cypherQueues.totalInWaitingQueues > 0:
             # numFlares = self.cypherQueues.totalInWaitingQueues / 10
-
             for k in range(3):
                 print(f'sending flare (max 3) {k}')
                 self.pubsub.publish_message('awaken')
@@ -417,6 +432,7 @@ class CypherTransactionBlockWorker:
                     ctBlock.registerChangeInSql('outOfWorkingQ')
                 ctBlock.setJson()
                 self.cypherQueues.pushCtbToCompletedQ(ctBlock)
+                ctBlock.registerChangeInSql('error', repr(e))
                 return False
 
             except Exception as e:
@@ -432,28 +448,30 @@ class CypherTransactionBlockWorker:
         duration = []
         statementList = []
         for statement in statements:
-            try:
-                startTs = datetime.now(timezone.utc)
-                if "batch" in statement:
-                    res = tx.run(statement["cypher"],
-                                 statement["parameters"],
-                                 batch=statement["batch"])
-                else:
-                    res = tx.run(statement["cypher"],
-                                 statement["parameters"])
-                results.append(res)
+            # try:
+            startTs = datetime.now(timezone.utc)
+            if "batch" in statement:
+                cyph = statement["cypher"][0:100]
+                print(f'batch-mode statement[cypher] to be run: {cyph}')
+                res = tx.run(statement["cypher"],
+                             statement["parameters"],
+                             batch=statement["batch"])
+            else:
+                cyph = statement["cypher"][0:100]
+                print(f'statement[cypher] to be run: {cyph}')
+                res = tx.run(statement["cypher"],
+                             statement["parameters"])
+            results.append(res)
 
-                endTs = datetime.now(timezone.utc)
-                duration.append(um.dateDiff('sec', startTs, endTs))
-                statementList.append({"cypher": statement["cypher"], "parameters": statement["parameters"], "duration": um.dateDiff('sec', startTs, endTs),
-                                      "status": "OK", "error": None})
-            except Exception as e:
-                endTs = datetime.now(timezone.utc)
-                duration.append(um.dateDiff('sec', startTs, endTs))
-                logging.error(repr(e))
-                statementList.append({"cypher": statement["cypher"], "parameters": statement["parameters"], "duration": um.dateDiff('sec', startTs, endTs),
-                                      "status": "ERROR", "error": repr(e)})
-
-                return False
+            endTs = datetime.now(timezone.utc)
+            duration.append(um.dateDiff('sec', startTs, endTs))
+            statementList.append({"cypher": statement["cypher"], "parameters": statement["parameters"], "duration": um.dateDiff('sec', startTs, endTs),
+                                  "status": "OK", "error": None})
+            # except Exception as e:
+            #    endTs = datetime.now(timezone.utc)
+            #    duration.append(um.dateDiff('sec', startTs, endTs))
+            #    logging.error(repr(e))
+            #    statementList.append({"cypher": statement["cypher"], "parameters": statement["parameters"], "duration": um.dateDiff('sec', startTs, endTs),
+            #                          "status": "ERROR", "error": repr(e)})
 
         return results, statementList
